@@ -19,14 +19,28 @@ class TestNtk(unittest.TestCase, Ntk):
     without_stop_words_without_tag_map_doc_filtered = 'good case excellent value i am agree there is a mistake item doe not match picture'
     def __init__(self, *args, **kwargs):
         self.ntk = Ntk()
+        self.ntk_no_stop_words = Ntk({'stop_words': []})
         self.docs = nltk.sent_tokenize(self.doc)
         self.target = [1, 1, 0, 0]
         self.tuples = self.ntk.create_tuples(self.docs, self.target)
         unittest.TestCase.__init__(self, *args, **kwargs)
 
-    def test_doc_cleaned(self):
-        self.assertEqual(self.ntk.get_doc_cleaned(self.doc), self.default_doc_filtered)
+    def test_get_tokens_cleaned(self):
+        tokens = self.ntk_no_stop_words.get_tokens_cleaned(self.docs[0])
+        self.assertEqual(tokens, ['good', 'case', 'excellent', 'value'])
+        tokens = self.ntk_no_stop_words.get_tokens_cleaned(self.docs[1], is_lemma = True)
+        self.assertEqual(tokens, ['i', 'be', 'agree'])
+        tokens = self.ntk_no_stop_words.get_tokens_cleaned(self.docs[1], is_lemma = False)
+        self.assertEqual(tokens, ['i', 'am', 'agree'])
 
+        tokens = self.ntk.get_tokens_cleaned(self.docs[1], is_lemma = False)
+        self.assertEqual(tokens, ['agree'])
+
+    def test_get_doc_cleaned(self):
+        self.assertEqual(self.ntk.get_doc_cleaned(self.doc), self.default_doc_filtered)
+        self.assertEqual(self.ntk_no_stop_words.get_doc_cleaned(self.doc), self.without_stop_words_doc_filtered)
+
+    def test_doc_cleaned(self):
         vocab_token = self.ntk.create_vocab_from_docs(self.docs, False)
         self.assertEqual(len(vocab_token), 9)
         self.assertEqual(self.ntk.get_stats_vocab(vocab_token), (9, 9))
@@ -76,28 +90,25 @@ class TestNtk(unittest.TestCase, Ntk):
         self.assertEqual(ntk.get_doc_cleaned(self.doc), self.default_doc_filtered)
 
     def test_doc_cleaned_without_stop_words(self):
-        ntk = Ntk({'stop_words': []})
-        self.assertEqual(ntk.get_doc_cleaned(self.doc), self.without_stop_words_doc_filtered)
-
-        vocab_token = ntk.create_vocab_from_docs(self.docs, False)
+        vocab_token = self.ntk_no_stop_words.create_vocab_from_docs(self.docs, False)
         self.assertEqual(len(vocab_token), 16)
         self.assertEqual(vocab_token['am'], 1)
         self.assertEqual(vocab_token['is'], 1)
         self.assertEqual(vocab_token['does'], 1)
-        self.assertEqual(ntk.get_stats_vocab(vocab_token), (16, 16))
-        self.assertEqual(ntk.get_stats_vocab(vocab_token, 2), (0, 16))
+        self.assertEqual(self.ntk_no_stop_words.get_stats_vocab(vocab_token), (16, 16))
+        self.assertEqual(self.ntk_no_stop_words.get_stats_vocab(vocab_token, 2), (0, 16))
 
-        vocab_lemma = ntk.create_vocab_from_docs(self.docs, True)
+        vocab_lemma = self.ntk_no_stop_words.create_vocab_from_docs(self.docs, True)
         self.assertEqual(len(vocab_lemma), 15)
         self.assertEqual(vocab_lemma['be'], 2)
         self.assertEqual(vocab_lemma['do'], 1)
-        self.assertEqual(ntk.get_stats_vocab(vocab_lemma), (15, 15))
-        self.assertEqual(ntk.get_stats_vocab(vocab_lemma, 2), (1, 15))
+        self.assertEqual(self.ntk_no_stop_words.get_stats_vocab(vocab_lemma), (15, 15))
+        self.assertEqual(self.ntk_no_stop_words.get_stats_vocab(vocab_lemma, 2), (1, 15))
 
-        features_token = ntk.create_features_from_tuples(self.tuples, False)
+        features_token = self.ntk_no_stop_words.create_features_from_tuples(self.tuples, False)
         self.assertEqual(features_token[1], ({'words_top': 0, 'neg': 0.0, 'neu': 0.286, 'pos': 0.714, 'compound': 0.3612}, 1))
 
-        features_lemma = ntk.create_features_from_tuples(self.tuples, True)
+        features_lemma = self.ntk_no_stop_words.create_features_from_tuples(self.tuples, True)
         self.assertEqual(features_lemma[1], ({'words_top': 0, 'neg': 0.0, 'neu': 0.286, 'pos': 0.714, 'compound': 0.3612}, 1))
 
         words_top = self.ntk.get_words_top(vocab_token, 4)
@@ -106,19 +117,19 @@ class TestNtk(unittest.TestCase, Ntk):
 
         docs_cleaned = []
         for doc in self.docs:
-            docs_cleaned.append(ntk.get_doc_cleaned(doc, False))
-        tuples = ntk.create_tuples(docs_cleaned, self.target)
-        vocab_token = ntk.create_vocab_from_tuples(tuples, False)
-        self.assertEqual(ntk.get_stats_vocab(vocab_token), (16, 16))
-        self.assertEqual(ntk.get_stats_vocab(vocab_token, 2), (0, 16))
+            docs_cleaned.append(self.ntk_no_stop_words.get_doc_cleaned(doc, False))
+        tuples = self.ntk_no_stop_words.create_tuples(docs_cleaned, self.target)
+        vocab_token = self.ntk_no_stop_words.create_vocab_from_tuples(tuples, False)
+        self.assertEqual(self.ntk_no_stop_words.get_stats_vocab(vocab_token), (16, 16))
+        self.assertEqual(self.ntk_no_stop_words.get_stats_vocab(vocab_token, 2), (0, 16))
 
         docs_cleaned = []
         for doc in self.docs:
-            docs_cleaned.append(ntk.get_doc_cleaned(doc, True))
-        tuples = ntk.create_tuples(docs_cleaned, self.target)
-        vocab_token = ntk.create_vocab_from_tuples(tuples)
-        self.assertEqual(ntk.get_stats_vocab(vocab_token), (15, 15))
-        self.assertEqual(ntk.get_stats_vocab(vocab_token, 2), (1, 15))
+            docs_cleaned.append(self.ntk_no_stop_words.get_doc_cleaned(doc, True))
+        tuples = self.ntk_no_stop_words.create_tuples(docs_cleaned, self.target)
+        vocab_token = self.ntk_no_stop_words.create_vocab_from_tuples(tuples)
+        self.assertEqual(self.ntk_no_stop_words.get_stats_vocab(vocab_token), (15, 15))
+        self.assertEqual(self.ntk_no_stop_words.get_stats_vocab(vocab_token, 2), (1, 15))
 
     def test_doc_cleaned_without_stop_words_with_min_length(self):
         ntk = Ntk({'stop_words': [], 'min_length': 2})
@@ -234,15 +245,14 @@ class TestNtk(unittest.TestCase, Ntk):
         np.testing.assert_array_equal(ngrams, tokens)
 
     def test_get_ngrams_features(self):
-        ntk = Ntk({'stop_words': []})
-        tokens = ntk.get_tokens_cleaned(self.doc, is_lemma = False)
-        features = ntk.get_ngrams_features()
+        tokens = self.ntk_no_stop_words.get_tokens_cleaned(self.doc, is_lemma = False)
+        features = self.ntk_no_stop_words.get_ngrams_features()
         self.assertEqual(features, {})
-        tokens_features = ntk.get_ngrams_features(degree = 1, tokens = tokens)
+        tokens_features = self.ntk_no_stop_words.get_ngrams_features(degree = 1, tokens = tokens)
         self.assertEqual(tokens_features, {'good': 1, 'case': 1, 'excellent': 1, 'value': 1, 'i': 1, 'am': 1, 'agree': 1, 'there': 1, 'is': 1, 'a': 1, 'mistake': 1, 'item': 1, 'does': 1, 'not': 1, 'match': 1, 'picture': 1})
-        doc_features = ntk.get_ngrams_features(degree = 1, doc = self.doc)
+        doc_features = self.ntk_no_stop_words.get_ngrams_features(degree = 1, doc = self.doc)
         self.assertEqual(doc_features, tokens_features)
-        features = ntk.get_ngrams_features(degree = 1, doc = self.doc, is_lemma = True)
+        features = self.ntk_no_stop_words.get_ngrams_features(degree = 1, doc = self.doc, is_lemma = True)
         self.assertEqual(features, {'good': 1, 'case': 1, 'excellent': 1, 'value': 1, 'i': 1, 'be': 1, 'agree': 1, 'there': 1, 'a': 1, 'mistake': 1, 'item': 1, 'do': 1, 'not': 1, 'match': 1, 'picture': 1})
 
     def test_create_ngrams_features_from_docs(self):
@@ -257,6 +267,14 @@ class TestNtk(unittest.TestCase, Ntk):
         self.assertEqual(features[0][1], True)
         self.assertEqual(features[1][0], {})
 
+    def test_get_features(self):
+        features = self.ntk.get_features(self.docs[0])
+        self.assertEqual(features, {'words_top': 0, 'neg': 0.0, 'neu': 0.1, 'pos': 0.9, 'compound': 0.8402})
+        features = self.ntk_no_stop_words.get_features(self.docs[1], is_lemma = True, degree = 1)
+        self.assertEqual(features, {'words_top': 0, 'i': 1, 'be': 1, 'agree': 1, 'neg': 0.0, 'neu': 0.286, 'pos': 0.714, 'compound': 0.3612})
+        features = self.ntk_no_stop_words.get_features(self.docs[1], is_lemma = False, degree = 1)
+        self.assertEqual(features, {'words_top': 0, 'i': 1, 'am': 1, 'agree': 1, 'neg': 0.0, 'neu': 0.286, 'pos': 0.714, 'compound': 0.3612})
+
     def create_words_map(self):
         tokens = self.ntk.get_tokens_cleaned(self.doc)
         return self.ntk.create_words_map(tokens)
